@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -1101,7 +1101,7 @@ Build_Display_Lists (void)
 #endif
 	      mav_listPointerReset (c->features);
 	      while (mav_listItemNext (c->features, (void **)&cobj))
-		mav_callbackDrawExec (mav_win_current, obj, NULL);
+		mav_callbackDrawExec (mav_win_current, cobj, NULL);
 #ifdef MAV_GL
 	      closeobj ();
 #else
