@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -31,7 +31,7 @@
 #include <string.h>
 #include <math.h>
 #include <stdlib.h>
-#ifdef WIN32
+#if defined(WIN32) || defined(__CYGWIN__)
 #include <windows.h>
 #endif
 #include <GL/glu.h>
@@ -311,10 +311,26 @@ Feature *feature;
 int feature_vertices;
 int num_polygons;
 
+/* For old versions of GLU */
+
+#ifndef GLU_VERSION_1_2
+#define GLUtesselator GLUtriangulatorObj
+#define gluTessBeginPolygon(X,Y) gluBeginPolygon((X))
+#define gluTessBeginContour(X) gluNextContour((X), GLU_UNKNOWN)
+#define gluTessEndContour(X) 
+#define gluTessEndPolygon(X) gluEndPolygon((X))
+#endif
+
 #ifndef CALLBACK
 #define CALLBACK
 #endif
 
+#ifdef __CYGWIN__
+typedef void (*MAVLIB_GLUCB)();
+#else
+typedef void (CALLBACK *MAVLIB_GLUCB)();
+#endif
+
 void CALLBACK my_begin(GLenum mode)
 {
   feature->polys[feature->num_polys].num_verts= 3;
@@ -354,7 +370,7 @@ void CALLBACK count_polygons(void *v)
   }
 }
 
-void CALLBACK my_edge_flag(GLboolean flag)
+void CALLBACK my_edge_flag(GLboolean f)
 {
 }
 
@@ -362,7 +378,7 @@ void Build_Feature(FILE *file, int type)
 {
   MAV_vector *verts;
   GLdouble data[3];
-  GLUtriangulatorObj *tobj;
+  GLUtesselator *tobj;
   int i, num_verts;
 
   feature= mav_malloc(sizeof(Feature));
@@ -389,22 +405,22 @@ void Build_Feature(FILE *file, int type)
   /* initialise a triangulator object */
   tobj= gluNewTess();
   if (!tobj) {
-    fprintf(stderr, "Failed to allocate gluTriangulatorObj\n");
+    fprintf(stderr, "Failed to allocate GLUtesselator\n");
     exit(0);
   }
 
   /* set triangulator callbacks to count triangles */
   feature->num_polys= 0;
   feature_vertices= 0;
-  gluTessCallback(tobj, GLU_BEGIN, NULL);
-  gluTessCallback(tobj, GLU_END, NULL);
-  gluTessCallback(tobj, GLU_ERROR, my_error);
-  gluTessCallback(tobj, GLU_VERTEX, count_polygons);
-  gluTessCallback(tobj, GLU_EDGE_FLAG, my_edge_flag);
+  gluTessCallback(tobj, GLU_TESS_BEGIN, NULL);
+  gluTessCallback(tobj, GLU_TESS_END, NULL);
+  gluTessCallback(tobj, GLU_TESS_ERROR, (MAVLIB_GLUCB) my_error);
+  gluTessCallback(tobj, GLU_TESS_VERTEX, (MAVLIB_GLUCB) count_polygons);
+  gluTessCallback(tobj, GLU_TESS_EDGE_FLAG, (MAVLIB_GLUCB) my_edge_flag);
 
   /* count polygons */
-  gluBeginPolygon(tobj);
-  gluNextContour(tobj, GLU_UNKNOWN);
+  gluTessBeginPolygon(tobj, NULL);
+  gluTessBeginContour(tobj);
   for (i=0; i<num_verts; i++) {
     data[0]= (GLdouble)verts[i].x;
     data[1]= (GLdouble)verts[i].y;
@@ -412,7 +428,8 @@ void Build_Feature(FILE *file, int type)
       
     gluTessVertex(tobj, data, (GLvoid *)&verts[i]);
   }
-  gluEndPolygon(tobj);
+  gluTessEndContour(tobj);
+  gluTessEndPolygon(tobj);
   gluDeleteTess(tobj);
 
   /* allocate space for polygons */
@@ -425,20 +442,20 @@ void Build_Feature(FILE *file, int type)
   /* re-initialise triangulatorObj for triangulation */
   tobj= gluNewTess();
   if (!tobj) {
-    fprintf(stderr, "Failed to allocate gluTriangulatorObj\n");
+    fprintf(stderr, "Failed to allocate GLUtesselator\n");
     exit(0);
   }
 
   feature->num_polys= 0;
-  gluTessCallback(tobj, GLU_BEGIN, my_begin);
-  gluTessCallback(tobj, GLU_END, NULL);
-  gluTessCallback(tobj, GLU_ERROR, my_error);
-  gluTessCallback(tobj, GLU_VERTEX, my_vertex);
-  gluTessCallback(tobj, GLU_EDGE_FLAG, my_edge_flag);
+  gluTessCallback(tobj, GLU_TESS_BEGIN, (MAVLIB_GLUCB) my_begin);
+  gluTessCallback(tobj, GLU_TESS_END, NULL);
+  gluTessCallback(tobj, GLU_TESS_ERROR, (MAVLIB_GLUCB) my_error);
+  gluTessCallback(tobj, GLU_TESS_VERTEX, (MAVLIB_GLUCB) my_vertex);
+  gluTessCallback(tobj, GLU_TESS_EDGE_FLAG, (MAVLIB_GLUCB) my_edge_flag);
 
   /* triangulate */
-  gluBeginPolygon(tobj);
-  gluNextContour(tobj, GLU_UNKNOWN);
+  gluTessBeginPolygon(tobj, NULL);
+  gluTessBeginContour(tobj);
   for (i=0; i<num_verts; i++) {
     data[0]= (double)verts[i].x;
     data[1]= (double)verts[i].y;
@@ -446,7 +463,8 @@ void Build_Feature(FILE *file, int type)
     
     gluTessVertex(tobj, data, (void *)&verts[i]);
   }
-  gluEndPolygon(tobj);
+  gluTessEndContour(tobj);
+  gluTessEndPolygon(tobj);
   gluDeleteTess(tobj);
 
   /* initialise matrix */
