@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -54,7 +54,7 @@
 #include <math.h>
 #include "lcity2_colour.h"
 #include <string.h>
-#ifdef WIN32
+#if defined(WIN32) || defined(__CYGWIN__)
 #include <windows.h>
 #endif
 #include <GL/glu.h>
@@ -758,10 +758,26 @@ void Make_Font(void)
 Feature *feature;
 int feature_vertices;
 
+/* For old versions of GLU */
+
+#ifndef GLU_VERSION_1_2
+#define GLUtesselator GLUtriangulatorObj
+#define gluTessBeginPolygon(X,Y) gluBeginPolygon((X))
+#define gluTessBeginContour(X) gluNextContour((X), GLU_UNKNOWN)
+#define gluTessEndContour(X) 
+#define gluTessEndPolygon(X) gluEndPolygon((X))
+#endif
+
 #ifndef CALLBACK
 #define CALLBACK
 #endif
 
+#ifdef __CYGWIN__
+typedef void (*MAVLIB_GLUCB)();
+#else
+typedef void (CALLBACK *MAVLIB_GLUCB)();
+#endif
+
 void CALLBACK my_begin(GLenum mode)
 {
   feature->polys[feature->num_polys].num_verts= 3;
@@ -791,7 +807,7 @@ void CALLBACK my_vertex(void *v)
   }
 }
 
-void CALLBACK dummyedge(GLboolean flag)
+void CALLBACK dummyedge(GLboolean f)
 {
 }
 
@@ -819,7 +835,7 @@ void CALLBACK dummyend(void)
 void Build_Feature(float *xp, float *yp, float *zp, int num_verts, int type)
 {
   GLdouble data[3];
-  GLUtriangulatorObj *tobj;
+  GLUtesselator *tobj;
   int i;
   float x1,y1,x1p,y1p,z1;
   float dx,dy,dz;
@@ -884,7 +900,7 @@ void Build_Feature(float *xp, float *yp, float *zp, int num_verts, int type)
   /* initialise a triangulator object */
   tobj= gluNewTess();
   if (!tobj) {
-    fprintf(stderr, "Failed to allocate gluTriangulatorObj\n");
+    fprintf(stderr, "Failed to allocate GLUtesselator\n");
     exit(0);
   }
 
@@ -892,22 +908,23 @@ void Build_Feature(float *xp, float *yp, float *zp, int num_verts, int type)
   feature->num_polys= 0;
   feature_vertices= 0;
   
-  gluTessCallback(tobj, GLU_BEGIN, dummybegin);
-  gluTessCallback(tobj, GLU_END, dummyend);
-  gluTessCallback(tobj, GLU_ERROR, my_error);
-  gluTessCallback(tobj, GLU_VERTEX, count_polygons);
-  gluTessCallback(tobj, GLU_EDGE_FLAG, dummyedge);
+  gluTessCallback(tobj, GLU_TESS_BEGIN, (MAVLIB_GLUCB) dummybegin);
+  gluTessCallback(tobj, GLU_TESS_END, (MAVLIB_GLUCB) dummyend);
+  gluTessCallback(tobj, GLU_TESS_ERROR, (MAVLIB_GLUCB) my_error);
+  gluTessCallback(tobj, GLU_TESS_VERTEX, (MAVLIB_GLUCB) count_polygons);
+  gluTessCallback(tobj, GLU_TESS_EDGE_FLAG, (MAVLIB_GLUCB) dummyedge);
 
   /* count polygons */
-  gluBeginPolygon(tobj);
-  gluNextContour(tobj, GLU_UNKNOWN);
+  gluTessBeginPolygon(tobj, NULL);
+  gluTessBeginContour(tobj);
   for (i=0; i<num_verts; i++) {
     data[0]= (GLdouble)feature->verts[i].x;
     data[1]= (GLdouble)feature->verts[i].y;
     data[2]= (GLdouble)feature->verts[i].z;
     gluTessVertex(tobj, data, (GLvoid *)&(feature->verts[i]));
   }
-  gluEndPolygon(tobj);
+  gluTessEndContour(tobj);
+  gluTessEndPolygon(tobj);
   gluDeleteTess(tobj);
 
   /* allocate space for polygons */
@@ -921,20 +938,20 @@ void Build_Feature(float *xp, float *yp, float *zp, int num_verts, int type)
   /* re-initialise triangulatorObj for triangulation */
   tobj= gluNewTess();
   if (!tobj) {
-    fprintf(stderr, "Failed to allocate gluTriangulatorObj\n");
+    fprintf(stderr, "Failed to allocate GLUtesselator\n");
     exit(0);
   }
 
   feature->num_polys= 0;
-  gluTessCallback(tobj, GLU_BEGIN, my_begin);
-  gluTessCallback(tobj, GLU_END, dummyend);
-  gluTessCallback(tobj, GLU_ERROR, my_error);
-  gluTessCallback(tobj, GLU_VERTEX, my_vertex);
-  gluTessCallback(tobj, GLU_EDGE_FLAG, dummyedge); /* JMC */
+  gluTessCallback(tobj, GLU_TESS_BEGIN, (MAVLIB_GLUCB) my_begin);
+  gluTessCallback(tobj, GLU_TESS_END, (MAVLIB_GLUCB) dummyend);
+  gluTessCallback(tobj, GLU_TESS_ERROR, (MAVLIB_GLUCB) my_error);
+  gluTessCallback(tobj, GLU_TESS_VERTEX, (MAVLIB_GLUCB) my_vertex);
+  gluTessCallback(tobj, GLU_TESS_EDGE_FLAG, (MAVLIB_GLUCB) dummyedge); /* JMC */
 
   /* triangulate */
-  gluBeginPolygon(tobj);
-  gluNextContour(tobj, GLU_UNKNOWN);
+  gluTessBeginPolygon(tobj, NULL);
+  gluTessBeginContour(tobj);
   for (i=0; i<num_verts; i++) {
     data[0]= (double)feature->verts[i].x;
     data[1]= (double)feature->verts[i].y;
@@ -942,7 +959,8 @@ void Build_Feature(float *xp, float *yp, float *zp, int num_verts, int type)
 
     gluTessVertex(tobj, data, (void *)&(feature->verts[i]));
   }
-  gluEndPolygon(tobj);
+  gluTessEndContour(tobj);
+  gluTessEndPolygon(tobj);
   gluDeleteTess(tobj);
 
   /* initialise matrix */
