@@ -21,7 +21,7 @@
  The authors can be contacted via:
  www   - http://aig.cs.man.ac.uk
  email - maverik@aig.cs.man.ac.uk
- mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
+ mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
          University of Manchester, Manchester, M13 9PL, UK
 */
 
@@ -30,7 +30,6 @@
 #ifdef WIN32
 #include <windows.h>
 #endif
-#include <GL/gl.h>
 #include <stdio.h>
 
 
@@ -80,14 +79,14 @@ int Keyboard_Function(MAV_object *obj, MAV_keyboardEvent *ev)
       if (fog_distance < 1.0) fog_distance= 1.0;
       if (box_distance > fog_distance) box_distance= fog_distance;
       fprintf(stdout, "Fog distance= %f\n", fog_distance);
-      glFogf(GL_FOG_END, fog_distance);
+      mav_windowFogSet(mav_win_all, MAV_FOG_LINEAR, 1.0, fog_distance, -1,-1,-1);
       rv=1;
       break;
 
     case '=': /* increase fog distance */
       fog_distance+=10.0;
       fprintf(stdout, "Fog distance= %f\n", fog_distance);
-      glFogf(GL_FOG_END, fog_distance);
+      mav_windowFogSet(mav_win_all, MAV_FOG_LINEAR, 1.0, fog_distance, -1,-1,-1);
       rv=1;
       break;
 
@@ -111,12 +110,12 @@ int Keyboard_Function(MAV_object *obj, MAV_keyboardEvent *ev)
       
       if (apply_fog) 	
       {
-	glEnable(GL_FOG);
+	mav_windowFogSet(mav_win_all, MAV_FOG_LINEAR, 1.0, fog_distance, -1,-1,-1);
 	fprintf(stderr, "enabled fog\n");
       }
       else
       {
-	glDisable(GL_FOG);
+	mav_windowFogSet(mav_win_all, MAV_FOG_NONE, 1.0, fog_distance, -1,-1,-1);
 	fprintf(stderr, "disabled fog\n");
       }
       break;
@@ -136,7 +135,6 @@ int Keyboard_Function(MAV_object *obj, MAV_keyboardEvent *ev)
 int main(int argc, char *argv[])
 {
   MAV_viewParams vp;
-  GLfloat fogColour[4]= { 0.0, 0.0, 0.0, 1.0 };
 
   if (!(argc==1 || argc==2)) {
     printf("usage %s: [amsterdam|manhattan|karlsruhe]\n", argv[0]);
@@ -248,19 +246,8 @@ int main(int argc, char *argv[])
   vp.mod= NULL;
   mav_windowViewParamsSet(mav_win_all, &vp);
 
-/* 
-   activate fog -  bit of a hack. Should really go through Maverik to define this
-   to make it active for all windows and machine independent. However, this in not 
-   yet implemented.
-*/
-
-  glFogi(GL_FOG_MODE, GL_LINEAR);
-  glFogfv(GL_FOG_COLOR, fogColour);
-  glFogf(GL_FOG_DENSITY, 0.01);
-  /*  glHint(GL_FOG_HINT, GL_FASTEST);*/
-  glFogf(GL_FOG_START, 1.0);
-  glFogf(GL_FOG_END, fog_distance);
-  glEnable(GL_FOG);
+  /* fog - a linear fade to background colour between 1.0 and fog_distance */
+  mav_windowFogSet(mav_win_all, MAV_FOG_LINEAR, 1.0, fog_distance, -1,-1,-1);
 
   fprintf(stderr, "*** press h for controls ***\n");
 
